@@ -67,7 +67,7 @@ public:
         EnabledRole,
     };
     explicit ServicesModel(QObject *parent = nullptr);
-    virtual ~ServicesModel();
+    ~ServicesModel() override;
 
     QHash<int, QByteArray> roleNames() const override;
     int rowCount(const QModelIndex &parent = QModelIndex()) const override;
